about summary refs log tree commit diff
diff options
context:
space:
mode:
authorUlrich Drepper <drepper@redhat.com>2007-10-05 21:25:32 +0000
committerUlrich Drepper <drepper@redhat.com>2007-10-05 21:25:32 +0000
commit0304f168cec7923e2ed1ccf67a0e79ec960318bb (patch)
treefc989b274800f1491b7b024e1de56e457b471d64
parenta83b5649c561758f914a4e393c42fbb595852cf7 (diff)
downloadglibc-0304f168cec7923e2ed1ccf67a0e79ec960318bb.tar.gz
glibc-0304f168cec7923e2ed1ccf67a0e79ec960318bb.tar.xz
glibc-0304f168cec7923e2ed1ccf67a0e79ec960318bb.zip
[BZ #5104]
	* elf/do-lookup.h (do_lookup_x): Don't ignore STT_COMMON symbols.
-rw-r--r--ChangeLog3
-rw-r--r--NEWS12
-rw-r--r--elf/do-lookup.h3
3 files changed, 16 insertions, 2 deletions
diff --git a/ChangeLog b/ChangeLog
index 6e830311a5..9105e3a9f5 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,8 @@
 2007-10-05  Ulrich Drepper  <drepper@redhat.com>
 
+	[BZ #5104]
+	* elf/do-lookup.h (do_lookup_x): Don't ignore STT_COMMON symbols.
+
 	[BZ #5113]
 	* string/bits/string2.h (__strdup): Cast parameters to calloc to
 	avoid warning with -Wconversion.
diff --git a/NEWS b/NEWS
index 0c5080025c..82dbdb1202 100644
--- a/NEWS
+++ b/NEWS
@@ -1,4 +1,4 @@
-GNU C Library NEWS -- history of user-visible changes.  2007-9-19
+GNU C Library NEWS -- history of user-visible changes.  2007-10-5
 Copyright (C) 1992-2006, 2007 Free Software Foundation, Inc.
 See the end for copying conditions.
 
@@ -24,6 +24,9 @@ Version 2.7
 
 * More CPU set manipulation functions.  Implemented by Ulrich Drepper.
 
+* New Linux interfaces: signalfd, eventfd, eventfd_read, and eventfd_write.
+  Implemented by Ulrich Drepper.
+
 * Handle private futexes in the NPTL implementation.
   Implemented by Jakub Jelinek and Ulrich Drepper.
 
@@ -34,6 +37,13 @@ Version 2.7
 
 * SHA-256 and SHA-512 based password encryption.
   Implemented by Ulrich Drepper.
+
+* New locales: ber_DZ, ber_MA, en_NG, fil_PH, fur_IT, fy_DE, ha_NG, ig_NG,
+  ik_CA, iu_CA, li_BE, li_NL, nds_DE, nds_NL, pap_AN, sc_IT, tk_TM, ug_CN,
+  yo_NG.
+
++ New iconv modules: MAC-CENTRALEUROPE, ISO-8859-9E, KOI8-RU.
+  Implemented by Ulrich Drepper.
 
 Version 2.6
 
diff --git a/elf/do-lookup.h b/elf/do-lookup.h
index e17d463526..ebb9ed5b47 100644
--- a/elf/do-lookup.h
+++ b/elf/do-lookup.h
@@ -87,8 +87,9 @@ do_lookup_x (const char *undef_name, uint_fast32_t new_hash,
 	  return NULL;
 
 	if (__builtin_expect (ELFW(ST_TYPE) (sym->st_info) > STT_FUNC
+			      && ELFW(ST_TYPE) (sym->st_info) != STT_COMMON
 			      && ELFW(ST_TYPE) (sym->st_info) != STT_TLS, 0))
 	  /* Ignore all but STT_NOTYPE, STT_OBJECT and STT_FUNC
 	     entries (and STT_TLS if TLS is supported) since these
 	     are no code/data definitions.  */
 	  return NULL;
@@ -87,8 +87,9 @@ do_lookup_x (const char *undef_name, uint_fast32_t new_hash,
 			      && ELFW(ST_TYPE) (sym->st_info) != STT_TLS, 0))
-	  /* Ignore all but STT_NOTYPE, STT_OBJECT and STT_FUNC
+	  /* Ignore all but STT_NOTYPE, STT_OBJECT, STT_FUNC, and STT_COMMON
 	     entries (and STT_TLS if TLS is supported) since these
 	     are no code/data definitions.  */